@@ -1,6 +1,6 @@
 #' Estimation of the Population Average Prescription Difference in Randomized Experiments Under Cross Validation
 #'
-#' This function estimates the Population Average Prescription Difference The details of the methods for this design are given in Imai and Li (2019).
+#' This function estimates the Population Average Prescription Difference with a budget constaint under cross validation. The details of the methods for this design are given in Imai and Li (2019).
 #'
 #'
 #'
@@ -13,7 +13,7 @@
 #' that the percentage of treatment units of That is lower than the budget constraint.
 #' @param Y The outcome variable of interest.
 #' @param ind A vector of integers (between 1 and number of folds inclusive) indicating which testing set does each sample belong to.
-#' @param plim The maximum percentage of population that can be treated under the
+#' @param budget The maximum percentage of population that can be treated under the
 #' budget constraint. Should be a decimal between 0 and 1.
 #' @param centered If \code{TRUE}, the outcome variables would be centered before processing. This minimizes
 #' the variance of the estimator. Default is \code{TRUE}.
@@ -26,15 +26,15 @@
 #' That2 = matrix(c(0,0,1,1,0,0,1,1,1,1,0,0,1,1,0,0), nrow = 8, ncol = 2)
 #' Y = c(4,5,0,2,4,1,-4,3)
 #' ind = c(rep(1,4),rep(2,4))
-#' papdlist <- PAPDcv(T, That, That2, Y, ind, plim = 0.5)
+#' papdlist <- PAPDcv(T, That, That2, Y, ind, budget = 0.5)
 #' papdlist$papd
 #' papdlist$sd
-#' @author Michael Lingzhi Li, Operations Research Center, Massachusetts Institute of Technology
-#' \email{mlli@mit.edu}, \url{http://mlli.mit.edu};
+#' @author Michael Lingzhi Li, Technology and Operations Management, Harvard Business School
+#' \email{mili@hbs.edu}, \url{https://www.michaellz.com/};
 #' @references Imai and Li (2019). \dQuote{Experimental Evaluation of Individualized Treatment Rules},
 #' @keywords evaluation
 #' @export PAPDcv
-PAPDcv <- function (T, Thatfp, Thatgp, Y, ind, plim, centered = TRUE) {
+PAPDcv <- function (T, Thatfp, Thatgp, Y, ind, budget, centered = TRUE) {
   if (!(identical(as.numeric(T),as.numeric(as.logical(T))))) {
     stop("T should be binary.")
   }
@@ -50,13 +50,13 @@ PAPDcv <- function (T, Thatfp, Thatgp, Y, ind, plim, centered = TRUE) {
   if ((length(T)!=dim(Thatfp)[1]) | (dim(Thatfp)[1]!=dim(Thatgp)[1]) | (dim(Thatgp)[1]!=length(Y))) {
     stop("All the data should have the same length.")
   }
-  if (!is.na(plim) & !(sum(sapply(1:max(ind),function(i) sum(Thatfp[ind==i, i])<=floor(length(T[ind==i])*plim) + 1))==max(ind))) {
-    stop("The number of treated units in Thatfp should be below or equal to plim.")
+  if (!is.na(budget) & !(sum(sapply(1:max(ind),function(i) sum(Thatfp[ind==i, i])<=floor(length(T[ind==i])*budget) + 1))==max(ind))) {
+    stop("The number of treated units in Thatfp should be below or equal to budget")
   }
-  if (!is.na(plim) & !(sum(sapply(1:max(ind),function(i) sum(Thatgp[ind==i, i])<=floor(length(T[ind==i])*plim) + 1))==max(ind))) {
-    stop("The number of treated units in Thatgp should be below or equal to plim.")
+  if (!is.na(budget) & !(sum(sapply(1:max(ind),function(i) sum(Thatgp[ind==i, i])<=floor(length(T[ind==i])*budget) + 1))==max(ind))) {
+    stop("The number of treated units in Thatgp should be below or equal to budget")
   }
-  if (((plim<0) | (plim>1))) {
+  if (((budget<0) | (budget>1))) {
     stop("Budget constraint should be between 0 and 1")
   }
   if (length(T)==0) {
@@ -81,7 +81,7 @@ PAPDcv <- function (T, Thatfp, Thatgp, Y, ind, plim, centered = TRUE) {
   kg1 = c()
   kg0 = c()
   for (i in 1:nfolds) {
-    output = PAPD(T[ind==i],Thatfp[ind==i,i],Thatgp[ind==i,i], Y[ind==i],plim)
+    output = PAPD(T[ind==i],Thatfp[ind==i,i],Thatgp[ind==i,i], Y[ind==i],budget)
     m = length(T[ind==i])
     m1 = sum(T[ind==i])
     m0 = m - m1
@@ -111,8 +111,8 @@ PAPDcv <- function (T, Thatfp, Thatgp, Y, ind, plim, centered = TRUE) {
   kg0 = mean(kg0)
   mF = n / nfolds
   SF2 = var(papdfold)
-  varfp=Sfgp1+Sfgp0-floor(mF*plim)*(mF-floor(mF*plim))/(mF^2*(mF-1))*(kf1^2+kg1^2)+
-    2*floor(mF*plim)*max(floor(mF*plim),mF-floor(mF*plim))/(mF^2*(mF-1))*abs(kf1*kg1)
+  varfp=Sfgp1+Sfgp0-floor(mF*budget)*(mF-floor(mF*budget))/(mF^2*(mF-1))*(kf1^2+kg1^2)+
+    2*floor(mF*budget)*max(floor(mF*budget),mF-floor(mF*budget))/(mF^2*(mF-1))*abs(kf1*kg1)
   vartotal = varfp - (nfolds - 1) / nfolds * min(varfp, SF2)
   return(list(papd=mean(papdfold),sd=sqrt(max(vartotal,0))))
 }
